from eu_country_codes import COUNTRY_CODES


def test_germany():
    assert "DE" in COUNTRY_CODES


def test_code_from_outside_eu():
    assert "ZW" not in COUNTRY_CODES


def test_gb_no_longer_in_eu():
    assert "GB" not in COUNTRY_CODES


def test_number_of_eu_countries():
    assert len(COUNTRY_CODES) == 27



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup


setup(name='pyeucountrycodes',
      version='1.2.0',
      description='All ISO 3166 country codes for EU countries.',
      author='Jürgen Gmach',
      author_email='juergen.gmach@googlemail.com',
      url='https://github.com/jugmac00/pyeucountrycodes',
      py_modules=['eu_country_codes'],
      python_requires='>=3.6',
     )
